SimpleAbsorbedShortwave
-------

.. inheritance-diagram:: climlab.radiation.SimpleAbsorbedShortwave
   :parts: 1
   :private-bases:

.. automodule:: climlab.radiation.absorbed_shorwave
    :members:
    :undoc-members:
    :show-inheritance:
